NTU Course Planner
==================

A Python program for NTU students to plan courses.

Course Schedule Updates
-----------------------

Updated for academic year 2015-16 semester 1 (*29/05/2015*)

Updated for academic year 2015-16 semester 2 (*19/11/2015*)

Updated for academic year 2016-17 semester 1 (*22/05/2016*)

Dependencies
------------

-  requests (2.5.0)
-  beautifulsoup4 (4.3.2)

If you know how to use *requirements.txt*, you can use that to help you
install these dependencies.

Download
--------

You can download this program
`here <https://github.com/koallen/NTUCoursePlanner/releases/tag/v1.0>`__

Usage
-----

To use this program, you can either clone this repo to your own computer
or download the ZIP file.

Then you can use the terminal to run this program by simply typing
``python3 planner.py``

The result which has all the possible combination of indexs is saved as
a text file called *result.txt*. Just open the folder where the code is
and you can see the file

Contribution
------------

If you would like to contribute to this project, please contact me via
the email in my profile page. Here are some improvements that I would
like to implement in the future if I have time: - Make it a package in
Python - Develop a front-end website as well as a back-end API for it
